API
===

This page contains the full reference to ``HookMan`` API.

.. contents::
    :depth: 3
    :local:


HookMan
-------

.. autoclass:: hookman.hooks.HookMan()
    :members:


.. _hook-specs-api-section:

HookSpecs
----------

.. autoclass:: hookman.hooks.HookSpecs()
    :members:

.. _plugin-info-api-section:

PluginInfo
----------

.. autoclass:: hookman.plugin_config.PluginInfo()
    :members:


.. _hookman-generator-api-section:

HookManGenerator
----------------

.. autoclass:: hookman.hookman_generator.HookManGenerator()
    :members:


Exception
----------

.. automodule:: hookman.exceptions
    :members:
